@@ -1,4 +1,4 @@
-import logging
+
 import io
 import typing as tp
 from satella.coding.concurrent import TerminableThread
@@ -6,7 +6,7 @@ import http.server
 from .. import getMetric
 from ..data import MetricData, MetricDataCollection
 
-logger = logging.getLogger(__name__)
+
 
 __all__ = ['metric_data_collection_to_prometheus', 'PrometheusHTTPExporterThread']
 
@@ -45,6 +45,7 @@ class PrometheusHTTPExporterThread(TerminableThread):
         service or the hostname
     :param enable_metric: whether to enable the metric
     """
+
     __slots__ = ('interface', 'port', 'httpd')
 
     def __init__(self, interface: str, port: int, extra_labels: tp.Optional[dict] = None,
